@@ -1,18 +1,11 @@
 """Embedding utils for queries."""
 
-from dataclasses import dataclass
 from typing import Callable, Dict, List, Optional, Tuple
 
-from gpt_index.data_structs.node_v2 import Node
+from gpt_index.data_structs.node_v2 import Node, NodeWithScore
 from gpt_index.embeddings.base import similarity as default_similarity_fn
 
 
-@dataclass
-class NodeWithScore:
-    node: Node
-    score: Optional[float]
-
-
 def get_top_k_embeddings(
     query_embedding: List[float],
     embeddings: List[List[float]],
