@@ -1,4 +1,4 @@
-"""Test Faiss index."""
+"""Test vector store indexes."""
 
 import sys
 from typing import Any, Dict, List, Tuple, cast
@@ -7,6 +7,7 @@ from unittest.mock import MagicMock, patch
 import numpy as np
 import pytest
 
+from gpt_index.data_structs.node_v2 import Node
 from gpt_index.embeddings.openai import OpenAIEmbedding
 from gpt_index.indices.vector_store.vector_indices import (
     GPTFaissIndex,
@@ -16,6 +17,7 @@ from gpt_index.readers.schema.base import Document
 from gpt_index.vector_stores.simple import SimpleVectorStore
 from tests.mock_utils.mock_decorator import patch_common
 from tests.mock_utils.mock_prompts import MOCK_REFINE_PROMPT, MOCK_TEXT_QA_PROMPT
+from gpt_index.data_structs.node_v2 import DocumentRelationship
 
 
 @pytest.fixture
@@ -632,3 +634,100 @@ def test_simple_async(
         vector_store = cast(SimpleVectorStore, index._vector_store)
         embedding = vector_store.get(text_id)
         assert (node.text, embedding) in actual_node_tups
+
+
+@patch_common
+@patch.object(
+    OpenAIEmbedding, "_get_text_embedding", side_effect=mock_get_text_embedding
+)
+@patch.object(
+    OpenAIEmbedding, "_get_text_embeddings", side_effect=mock_get_text_embeddings
+)
+@patch.object(
+    OpenAIEmbedding, "get_query_embedding", side_effect=mock_get_query_embedding
+)
+def test_simple_check_ids(
+    _mock_query_embed: Any,
+    _mock_text_embeds: Any,
+    _mock_text_embed: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    documents: List[Document],
+    struct_kwargs: Dict,
+) -> None:
+    """Test build GPTSimpleVectorIndex."""
+    index_kwargs, query_kwargs = struct_kwargs
+
+    ref_doc_id = "ref_doc_id_test"
+    source_rel = {DocumentRelationship.SOURCE: ref_doc_id}
+    nodes = [
+        Node("Hello world.", doc_id="node1", relationships=source_rel),
+        Node("This is a test.", doc_id="node2", relationships=source_rel),
+        Node("This is another test.", doc_id="node3", relationships=source_rel),
+        Node("This is a test v2.", doc_id="node4", relationships=source_rel),
+    ]
+    index = GPTSimpleVectorIndex(nodes, **index_kwargs)
+
+    # test query
+    query_str = "What is?"
+    response = index.query(query_str, **query_kwargs)
+    assert str(response) == ("What is?:This is another test.")
+    assert len(response.source_nodes) == 1
+    assert response.source_nodes[0].node.ref_doc_id == "ref_doc_id_test"
+    assert response.source_nodes[0].node.doc_id == "node3"
+    vector_store = cast(SimpleVectorStore, index._vector_store)
+    assert "node3" in vector_store._data.embedding_dict
+    assert "node3" in vector_store._data.text_id_to_doc_id
+
+
+@patch_common
+@patch.object(
+    OpenAIEmbedding, "_get_text_embedding", side_effect=mock_get_text_embedding
+)
+@patch.object(
+    OpenAIEmbedding, "_get_text_embeddings", side_effect=mock_get_text_embeddings
+)
+@patch.object(
+    OpenAIEmbedding, "get_query_embedding", side_effect=mock_get_query_embedding
+)
+def test_faiss_check_ids(
+    _mock_query_embed: Any,
+    _mock_texts_embed: Any,
+    _mock_text_embed: Any,
+    _mock_init: Any,
+    _mock_predict: Any,
+    _mock_total_tokens_used: Any,
+    _mock_split_text_overlap: Any,
+    _mock_split_text: Any,
+    documents: List[Document],
+    struct_kwargs: Dict,
+) -> None:
+    """Test embedding query."""
+    # NOTE: mock faiss import
+    sys.modules["faiss"] = MagicMock()
+    # NOTE: mock faiss index
+    faiss_index = MockFaissIndex()
+
+    index_kwargs, query_kwargs = struct_kwargs
+
+    ref_doc_id = "ref_doc_id_test"
+    source_rel = {DocumentRelationship.SOURCE: ref_doc_id}
+    nodes = [
+        Node("Hello world.", doc_id="node1", relationships=source_rel),
+        Node("This is a test.", doc_id="node2", relationships=source_rel),
+        Node("This is another test.", doc_id="node3", relationships=source_rel),
+        Node("This is a test v2.", doc_id="node4", relationships=source_rel),
+    ]
+
+    index = GPTFaissIndex(nodes, faiss_index=faiss_index, **index_kwargs)
+
+    # test query
+    query_str = "What is?"
+    response = index.query(query_str, **query_kwargs)
+    assert str(response) == ("What is?:This is another test.")
+    assert len(response.source_nodes) == 1
+    assert response.source_nodes[0].node.ref_doc_id == "ref_doc_id_test"
+    assert response.source_nodes[0].node.doc_id == "node3"
